fnss.netconfig.nodeconfig.add_stack — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.nodeconfig.add_stack

`add_stack`(topology, node, name, properties)

  Set stack on a node

  Parameters : | topology : Topology The topology node : any hashable type The ID of the node name : str The name of the stack properties : dict The properties of the stack

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »